require File.expand_path(File.join(File.dirname(__FILE__), 'spec_helper'))

RSpec.describe Appforce::Config do
  before do
    logger = Logger.new('/dev/null')
    Appforce::Spawn.logger = logger
  end

  describe 'DEFAULT_CONFIG_PATH' do
    it 'should have a default config path' do
      expect(Appforce::Config::DEFAULT_CONFIG_PATH).to end_with '.appforce'
    end

    context '.load_config' do
      it 'should load a config at a given path with method calls for keys in config' do
        Appforce::Config.load_config(file_fixture_path('appforce_config.yml'))
        @config = Appforce::Config.config
        expect(@config.api_host).to eq 'http://afuka.synctree.com'
        expect(@config.api_version).to eq 'VERSION_STRING'
        expect(@config.api_token).to eq 'INVALID_TOKEN'
      end

      it 'should raise an excpetion with a malformed config file' do
        expect { Appforce::Config.load_config(file_fixture_path('malformed_appforce_config.yml')) }.to raise_exception
      end
    end
    
    context '.dump_example_config' do
      before do
        allow(File).to receive(:expand_path).and_return("tmp")
      end

      it 'should write out a sample .appforce config file' do
        Appforce::Config.dump_example_config
        cfg = open_tmp_file('.appforce.example')
        expect(cfg).to match /PUT_API_TOKEN_HERE/
      end

      context 'errors while writing file' do
        before do
          allow(File).to receive(:open).and_raise(IOError)
        end

        it 'should raise an IOError excpetion' do
          expect { Appforce::Config.dump_example_config }.to raise_exception
        end
      end
    end
  end

end