require File.expand_path(File.join(File.dirname(__FILE__), 'spec_helper'))

RSpec.describe Appforce::Logger do
  before do
    logger = Logger.new('/dev/null')
    Appforce::Spawn.logger = logger
  end

  describe '.header' do
    context 'input string is under 74 chars in length' do
      before do
        @header = Appforce::Logger.header('This is a test header')
      end

      it 'should return a string' do
        expect(@header.class).to eq String
      end

      it 'should be 78 characters in length' do
        expect(@header.length).to eq 78
      end

      it 'should start with a blank space' do
        expect(@header).to start_with ' == '
      end

      it 'should end with an equals sign' do
        expect(@header).to end_with '='
      end

    end

    context 'input string is over 74 chars in length' do
      before do
        @header = Appforce::Logger.header('this is a really long string that is over seventy four characters long, I swear')
      end

      it 'should return a string' do
        expect(@header.class).to eq String
      end

      it 'should be greater than 78 characters in length' do
        expect(@header.length).to be > 78
      end

      it 'should start with a blank space' do
        expect(@header).to start_with ' == '
      end

      it 'should end with an equals sign' do
        expect(@header).to_not end_with '='
      end

    end
  end

  describe '.footer' do
    before do
      @footer = Appforce::Logger.footer
    end

    it 'should return a string' do
      expect(@footer.class).to eq String
    end

    it 'should be 78 characters in length' do
      expect(@footer.length).to eq 78
    end

    it 'should start with a space and an equals sign' do
      expect(@footer).to start_with ' ='
    end

    it 'should end with an equals sign' do
      expect(@footer).to end_with '='
    end

    it 'should contain only equals signs and a space at the front' do
      expect(@footer.scan('=').count).to  eq 77
      expect(@footer.scan(/\s/).count).to eq 1
    end

  end

end